Index: trunk/stac/src/stac.h
===================================================================
--- trunk/stac/src/stac.h	(revision 3673)
+++ trunk/stac/src/stac.h	(revision 5743)
@@ -18,5 +18,6 @@
 
 // Read the input files and return an array of images
-psArray *stacReadImages(psArray *filenames // The file names of the images
+psArray *stacReadImages(psArray **headers, // The image headers, to be returned
+			psArray *filenames // The file names of the images
     );
 
@@ -72,5 +73,5 @@
 
 // Print out a memblock when it's allocated --- this function used as a callback
-psMemoryId stacMemPrint(const psMemBlock *ptr);
+psMemId stacMemPrint(const psMemBlock *ptr);
 
 
